==> v0.3.0.zip: toxygen/README.md <==
# Toxygen

Toxygen is powerful cross-platform [Tox](https://tox.chat/) client written in pure Python3.

[![Release](https://img.shields.io/github/release/toxygen-project/toxygen.svg?style=flat)](https://github.com/toxygen-project/toxygen/releases/latest)
[![Stars](https://img.shields.io/github/stars/toxygen-project/toxygen.svg?style=flat)](https://github.com/toxygen-project/toxygen/stargazers)
[![Open issues](https://img.shields.io/github/issues/toxygen-project/toxygen.svg?style=flat)](https://github.com/toxygen-project/toxygen/issues)
[![License](https://img.shields.io/badge/license-GPLv3-blue.svg?style=flat)](https://raw.githubusercontent.com/toxygen-project/toxygen/master/LICENSE.md)
[![Build Status](https://travis-ci.org/toxygen-project/toxygen.svg?branch=master)](https://travis-ci.org/toxygen-project/toxygen)

### [Install](/docs/install.md) - [Contribute](/docs/contributing.md) - [Plugins](/docs/plugins.md) - [Compile](/docs/compile.md) - [Contact](/docs/contact.md) - [Updater](https://github.com/toxygen-project/toxygen_updater)

### Supported OS: Linux and Windows

### Features:

- [x] 1v1 messages
- [x] File transfers
- [x] Audio calls
- [x] Video calls
- [x] Plugins support
- [x] Chat history
- [x] Emoticons
- [x] Stickers
- [x] Screenshots
- [x] Name lookups (toxme.io support)
- [x] Save file encryption
- [x] Profile import and export
- [x] Faux offline messaging
- [x] Faux offline file transfers
- [x] Inline images
- [x] Message splitting
- [x] Proxy support
- [x] Avatars
- [x] Multiprofile
- [x] Multilingual
- [x] Sound notifications
- [x] Contact aliases
- [x] Contact blocking
- [x] Typing notifications
- [x] Changing nospam
- [x] File resuming
- [x] Read receipts
- [ ] Desktop sharing
- [ ] Group chats

### Downloads
[Releases](https://github.com/toxygen-project/toxygen/releases)

[Download last stable version](https://github.com/toxygen-project/toxygen/archive/master.zip)

[Download develop version](https://github.com/toxygen-project/toxygen/archive/develop.zip)

### Screenshots
*Toxygen on Ubuntu and Windows*
![Ubuntu](/docs/ubuntu.png)
![Windows](/docs/windows.png)

### Docs
[Check /docs/ for more info](/docs/)

Also visit [pythonhosted.org/Toxygen/](http://pythonhosted.org/Toxygen/)

[Wiki](https://wiki.tox.chat/clients/toxygen)

==> v0.4.0.zip: toxygen/README.md <==
# Toxygen

Toxygen is powerful cross-platform [Tox](https://tox.chat/) client written in pure Python3.

[![Release](https://img.shields.io/github/release/toxygen-project/toxygen.svg?style=flat)](https://github.com/toxygen-project/toxygen/releases/latest)
[![Stars](https://img.shields.io/github/stars/toxygen-project/toxygen.svg?style=flat)](https://github.com/toxygen-project/toxygen/stargazers)
[![Open issues](https://img.shields.io/github/issues/toxygen-project/toxygen.svg?style=flat)](https://github.com/toxygen-project/toxygen/issues)
[![License](https://img.shields.io/badge/license-GPLv3-blue.svg?style=flat)](https://raw.githubusercontent.com/toxygen-project/toxygen/master/LICENSE.md)
[![Build Status](https://travis-ci.org/toxygen-project/toxygen.svg?branch=master)](https://travis-ci.org/toxygen-project/toxygen)

### [Install](/docs/install.md) - [Contribute](/docs/contributing.md) - [Plugins](/docs/plugins.md) - [Compile](/docs/compile.md) - [Contact](/docs/contact.md) - [Updater](https://github.com/toxygen-project/toxygen_updater)

### Supported OS: Linux and Windows

### Features:

- 1v1 messages
- File transfers
- Audio calls
- Video calls
- Plugins support
- Desktop sharing
- Chat history
- Emoticons
- Stickers
- Screenshots
- Name lookups (toxme.io support)
- Save file encryption
- Profile import and export
- Faux offline messaging
- Faux offline file transfers
- Inline images
- Message splitting
- Proxy support
- Avatars
- Multiprofile
- Multilingual
- Sound notifications
- Contact aliases
- Contact blocking
- Typing notifications
- Changing nospam
- File resuming
- Read receipts

### Downloads
[Releases](https://github.com/toxygen-project/toxygen/releases)

[Download last stable version](https://github.com/toxygen-project/toxygen/archive/master.zip)

[Download develop version](https://github.com/toxygen-project/toxygen/archive/develop.zip)

### Screenshots
*Toxygen on Ubuntu and Windows*
![Ubuntu](/docs/ubuntu.png)
![Windows](/docs/windows.png)

### Docs
[Check /docs/ for more info](/docs/)

Also visit [pythonhosted.org/Toxygen/](http://pythonhosted.org/Toxygen/)

[Wiki](https://wiki.tox.chat/clients/toxygen)
